## cdist-type__install_fstab(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_fstab - generate /etc/fstab during installation

## 2. DESCRIPTION

Uses __install_generate_fstab to generate a /etc/fstab file and uploads it

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

prefix
  The prefix under which to generate the /etc/fstab file. Defaults to /target.

## 5. EXAMPLES

    __install_fstab
    __install_fstab --prefix /mnt/target

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__install_mount(7)
- cdist-type__install_generate_fstab(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).